==> lxqt-panel_0.14.1.orig.tar.xz: lxqt-panel-0.14.1/plugin-volume/translations/volume_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>LXQtVolume</name>
    <message>
        <location filename="../lxqtvolume.cpp" line="63"/>
        <source>Increase sound volume</source>
        <translation>Aumenta il volume</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="69"/>
        <source>Decrease sound volume</source>
        <translation>Riduci il volume</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="75"/>
        <source>Mute/unmute sound volume</source>
        <translation>Silenzia/rimuovi silenzio per il volume</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="136"/>
        <source>Volume Control: The following shortcuts can not be registered: %1</source>
        <translation>Controllo volume: la scorciatoia globale &apos;%1&apos; non può essere registrata</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="286"/>
        <source>Volume: %1%%2</source>
        <translation>Volume: %1%%2</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="286"/>
        <source>(muted)</source>
        <translation>(silenziato)</translation>
    </message>
</context>
<context>
    <name>LXQtVolumeConfiguration</name>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="14"/>
        <source>Volume Control Settings</source>
        <translation>Impostazioni controllo volume</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="20"/>
        <source>Device to control</source>
        <translation>Dispositivo da controllare</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="28"/>
        <source>ALSA</source>
        <translation>ALSA</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="35"/>
        <source>PulseAudio</source>
        <translation>PulseAudio</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="42"/>
        <source>OSS</source>
        <translation>OSS</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="57"/>
        <source>Behavior</source>
        <translation>Comportamento</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="63"/>
        <source>Mute on middle click</source>
        <translation>Silenzia al clic centrale del mouse</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="70"/>
        <source>Show on mouse click</source>
        <translation>Mostra al clic del mouse</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="77"/>
        <source>Allow volume beyond 100% (0dB)</source>
        <translation>Permetti volume oltre il 100% (0dB)</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="84"/>
        <source>Always notify about volume changes</source>
        <translation>Notifica sempre i cambiamenti di volume</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="99"/>
        <source>Volume adjust step</source>
        <translation>Passo di regolazione del volume</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="118"/>
        <source>External Mixer</source>
        <translation>Mixer esterno</translation>
    </message>
</context>
<context>
    <name>VolumePopup</name>
    <message>
        <location filename="../volumepopup.cpp" line="54"/>
        <source>Launch mixer</source>
        <translation>Avvia mixer</translation>
    </message>
    <message>
        <location filename="../volumepopup.cpp" line="55"/>
        <source>Mi&amp;xer</source>
        <translation>Mi&amp;xer</translation>
    </message>
</context>
</TS>

==> lxqt-panel_0.15.0.orig.tar.xz: lxqt-panel-0.15.0/plugin-volume/translations/volume_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>LXQtVolume</name>
    <message>
        <location filename="../lxqtvolume.cpp" line="64"/>
        <source>Increase sound volume</source>
        <translation>Aumenta il volume</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="70"/>
        <source>Decrease sound volume</source>
        <translation>Riduci il volume</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="76"/>
        <source>Mute/unmute sound volume</source>
        <translation>Silenzia/rimuovi silenzio per il volume</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="137"/>
        <source>Volume Control: The following shortcuts can not be registered: %1</source>
        <translation>Controllo volume: la scorciatoia globale &apos;%1&apos; non può essere registrata</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="291"/>
        <source>Volume: %1%%2</source>
        <translation>Volume: %1%%2</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="291"/>
        <source>(muted)</source>
        <translation>(silenziato)</translation>
    </message>
</context>
<context>
    <name>LXQtVolumeConfiguration</name>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="14"/>
        <source>Volume Control Settings</source>
        <translation>Impostazioni controllo volume</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="20"/>
        <source>Device to control</source>
        <translation>Dispositivo da controllare</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="28"/>
        <source>ALSA</source>
        <translation>ALSA</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="35"/>
        <source>PulseAudio</source>
        <translation>PulseAudio</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="42"/>
        <source>OSS</source>
        <translation>OSS</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="57"/>
        <source>Behavior</source>
        <translation>Comportamento</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="63"/>
        <source>Mute on middle click</source>
        <translation>Silenzia al clic centrale del mouse</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="70"/>
        <source>Show on mouse click</source>
        <translation>Mostra al clic del mouse</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="77"/>
        <source>Allow volume beyond 100% (0dB)</source>
        <translation>Permetti volume oltre il 100% (0dB)</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="84"/>
        <source>Always notify about volume changes</source>
        <translation>Notifica sempre i cambiamenti di volume</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="91"/>
        <source>Notify about volume changes with keyboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="106"/>
        <source>Volume adjust step</source>
        <translation>Passo di regolazione del volume</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="125"/>
        <source>External Mixer</source>
        <translation>Mixer esterno</translation>
    </message>
</context>
<context>
    <name>VolumePopup</name>
    <message>
        <location filename="../volumepopup.cpp" line="54"/>
        <source>Launch mixer</source>
        <translation>Avvia mixer</translation>
    </message>
    <message>
        <location filename="../volumepopup.cpp" line="55"/>
        <source>Mi&amp;xer</source>
        <translation>Mi&amp;xer</translation>
    </message>
</context>
</TS>
